@@ -320,7 +320,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
             local('if [[ -d "config" ]]; then echo "<collecting config>" ; rsync -ra --stats config/ dist/config; fi;')
             local('if [[ -d "src/public" ]]; then echo "<collecting public>" ; rsync -ra --stats src/public/ dist/public; fi;')
 
-        local('du -h %s' % yarn_cache)
+        local('du -hd1 %s' % yarn_cache)
 
     # make sure the new files are part of the local git repo
     #local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
